@@ -1,5 +1,5 @@
 /* GDA library
- * Copyright (C) 1998 - 2006 The GNOME Foundation.
+ * Copyright (C) 1998 - 2007 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
@@ -127,6 +127,10 @@ struct _GdaServerProviderClass {
 	const gchar           *(*get_def_dbms_type) (GdaServerProvider *provider,
 						     GdaConnection *cnc,
 						     GType g_type);
+	gchar                 *(*escape_string)     (GdaServerProvider *provider,
+						     GdaConnection *cnc, const gchar *str);
+	gchar                 *(*unescape_string)   (GdaServerProvider *provider,
+						     GdaConnection *cnc, const gchar *str);
 
 	/* connections management */
 	gboolean               (* open_connection) (GdaServerProvider *provider,
@@ -158,6 +162,10 @@ struct _GdaServerProviderClass {
 						     GdaConnection *cnc,
 						     GdaCommand *cmd,
 						     GdaParameterList *params);
+	GdaObject              *(* execute_query) (GdaServerProvider *provider,
+						   GdaConnection *cnc,
+						   GdaQuery *query,
+						   GdaParameterList *params);
 	char                   *(* get_last_insert_id) (GdaServerProvider *provider,
 							GdaConnection *cnc,
 							GdaDataModel *recset);
@@ -184,12 +192,6 @@ struct _GdaServerProviderClass {
 							const gchar *name, GError **error);
 
 	/* blobs */
-	GdaBlob                *(* create_blob) (GdaServerProvider *provider,
-						 GdaConnection *cnc);
-
-	GdaBlob                *(* fetch_blob) (GdaServerProvider *provider,
-						GdaConnection *cnc, const gchar *sql_id);
-
 	gpointer                   reserved1; /* is_reserved_word() ? */
 	gpointer                   reserved2; /* ping_or_reconnect() ? */
 	gpointer                   reserved3;
@@ -230,7 +232,10 @@ gchar                 *gda_server_provider_value_to_sql_string   (GdaServerProvi
 const gchar           *gda_server_provider_get_default_dbms_type (GdaServerProvider *provider,
 								  GdaConnection *cnc,
 								  GType type);
-
+gchar                 *gda_server_provider_escape_string         (GdaServerProvider *provider,
+								  GdaConnection *cnc, const gchar *str);
+gchar                 *gda_server_provider_unescape_string       (GdaServerProvider *provider,
+								  GdaConnection *cnc, const gchar *str);
 
 /* connections management */
 gboolean               gda_server_provider_open_connection  (GdaServerProvider *provider,
@@ -264,6 +269,10 @@ GList        *gda_server_provider_execute_command    (GdaServerProvider *provide
 						      GdaConnection *cnc,
 						      GdaCommand *cmd,
 						      GdaParameterList *params);
+GdaObject    *gda_server_provider_execute_query    (GdaServerProvider *provider,
+						    GdaConnection *cnc,
+						    GdaQuery *query,
+						    GdaParameterList *params);
 gchar        *gda_server_provider_get_last_insert_id (GdaServerProvider *provider,
 						      GdaConnection *cnc,
 						      GdaDataModel *recset);
@@ -286,12 +295,6 @@ gboolean      gda_server_provider_rollback_savepoint   (GdaServerProvider *provi
 gboolean      gda_server_provider_delete_savepoint     (GdaServerProvider *provider, GdaConnection *cnc, 
 							const gchar *name, GError **error);
 
-/* blobs */
-GdaBlob      *gda_server_provider_create_blob          (GdaServerProvider *provider,
-							GdaConnection *cnc);
-GdaBlob      *gda_server_provider_fetch_blob_by_id     (GdaServerProvider *provider,
-							GdaConnection *cnc, const gchar *sql_id);
-
 G_END_DECLS
 
 #endif
