@@ -1,6 +1,6 @@
 /* gda-handler-string.c
  *
- * Copyright (C) 2003 - 2006 Vivien Malerba
+ * Copyright (C) 2003 - 2007 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -22,6 +22,7 @@
 #include <string.h>
 #include <glib/gi18n-lib.h>
 #include <libgda/gda-util.h>
+#include <libgda/gda-server-provider.h>
 
 static void gda_handler_string_class_init (GdaHandlerStringClass * class);
 static void gda_handler_string_init (GdaHandlerString * wid);
@@ -38,16 +39,19 @@ static GValue      *gda_handler_string_get_value_from_str     (GdaDataHandler *d
 							       GType type);
 static GValue      *gda_handler_string_get_sane_init_value    (GdaDataHandler * dh, GType type);
 
-static guint        gda_handler_string_get_nb_gda_types       (GdaDataHandler *dh);
-static GType        gda_handler_string_get_gda_type_index     (GdaDataHandler *dh, guint index);
-static gboolean     gda_handler_string_accepts_gda_type       (GdaDataHandler * dh, GType type);
+static guint        gda_handler_string_get_nb_g_types       (GdaDataHandler *dh);
+static GType        gda_handler_string_get_g_type_index     (GdaDataHandler *dh, guint index);
+static gboolean     gda_handler_string_accepts_g_type       (GdaDataHandler * dh, GType type);
 
 static const gchar *gda_handler_string_get_descr              (GdaDataHandler *dh);
 
 struct  _GdaHandlerStringPriv {
-	gchar          *detailled_descr;
-	guint           nb_gda_types;
-	GType          *valid_gda_types;
+	gchar             *detailled_descr;
+	guint              nb_g_types;
+	GType             *valid_g_types;
+
+	GdaServerProvider *prov;
+	GdaConnection     *cnc;
 };
 
 /* get a pointer to the parents to be able to call their destructor */
@@ -91,9 +95,9 @@ gda_handler_string_data_handler_init (GdaDataHandlerIface *iface)
 	iface->get_value_from_sql = gda_handler_string_get_value_from_sql;
 	iface->get_value_from_str = gda_handler_string_get_value_from_str;
 	iface->get_sane_init_value = gda_handler_string_get_sane_init_value;
-	iface->get_nb_gda_types = gda_handler_string_get_nb_gda_types;
-	iface->accepts_gda_type = gda_handler_string_accepts_gda_type;
-	iface->get_gda_type_index = gda_handler_string_get_gda_type_index;
+	iface->get_nb_g_types = gda_handler_string_get_nb_g_types;
+	iface->accepts_g_type = gda_handler_string_accepts_g_type;
+	iface->get_g_type_index = gda_handler_string_get_g_type_index;
 	iface->get_descr = gda_handler_string_get_descr;
 }
 
@@ -114,9 +118,9 @@ gda_handler_string_init (GdaHandlerString * hdl)
 	/* Private structure */
 	hdl->priv = g_new0 (GdaHandlerStringPriv, 1);
 	hdl->priv->detailled_descr = _("Strings handler");
-	hdl->priv->nb_gda_types = 1;
-	hdl->priv->valid_gda_types = g_new0 (GType, 1);
-	hdl->priv->valid_gda_types[0] = G_TYPE_STRING;
+	hdl->priv->nb_g_types = 1;
+	hdl->priv->valid_g_types = g_new0 (GType, 1);
+	hdl->priv->valid_g_types[0] = G_TYPE_STRING;
 
 	gda_object_set_name (GDA_OBJECT (hdl), _("InternalString"));
 	gda_object_set_description (GDA_OBJECT (hdl), _("Strings representation"));
@@ -135,8 +139,13 @@ gda_handler_string_dispose (GObject   * object)
 	if (hdl->priv) {
 		gda_object_destroy_check (GDA_OBJECT (object));
 
-		g_free (hdl->priv->valid_gda_types);
-		hdl->priv->valid_gda_types = NULL;
+		g_free (hdl->priv->valid_g_types);
+		hdl->priv->valid_g_types = NULL;
+
+		if (hdl->priv->prov)
+			g_object_remove_weak_pointer (G_OBJECT (hdl->priv->prov), (gpointer) &(hdl->priv->prov));
+		if (hdl->priv->cnc)
+			g_object_remove_weak_pointer (G_OBJECT (hdl->priv->cnc), (gpointer) &(hdl->priv->cnc));
 
 		g_free (hdl->priv);
 		hdl->priv = NULL;
@@ -148,7 +157,7 @@ gda_handler_string_dispose (GObject   * object)
 
 /**
  * gda_handler_string_new
-  *
+ *
  * Creates a data handler for strings
  *
  * Returns: the new object
@@ -163,6 +172,39 @@ gda_handler_string_new (void)
 	return (GdaDataHandler *) obj;
 }
 
+/**
+ * gda_handler_string_new_with_provider
+ * @prov: a #GdaServerProvider object
+ * @cnc: a #GdaConnection object, or %NULL
+ *
+ * Creates a data handler for strings, which will use some specific methods implemented
+ * by the @prov object (possibly also @cnc).
+ *
+ * Returns: the new object
+ */
+GdaDataHandler *
+gda_handler_string_new_with_provider (GdaServerProvider *prov, GdaConnection *cnc)
+{
+	GObject *obj;
+	GdaHandlerString *dh;
+
+	g_return_val_if_fail (GDA_IS_SERVER_PROVIDER (prov), NULL);
+	g_return_val_if_fail (!cnc || GDA_IS_CONNECTION (cnc), NULL);
+
+	obj = g_object_new (GDA_TYPE_HANDLER_STRING, "dict", NULL, NULL);
+	dh = (GdaHandlerString*) obj;
+
+	dh->priv->prov = prov;
+	if (cnc)
+		dh->priv->cnc = cnc;
+
+	g_object_add_weak_pointer (G_OBJECT (prov), (gpointer) &(dh->priv->prov));
+	if (cnc)
+		g_object_add_weak_pointer (G_OBJECT (cnc), (gpointer) &(dh->priv->cnc));
+
+	return (GdaDataHandler *) obj;
+}
+
 static gchar *
 gda_handler_string_get_sql_from_value (GdaDataHandler *iface, const GValue *value)
 {
@@ -175,7 +217,10 @@ gda_handler_string_get_sql_from_value (GdaDataHandler *iface, const GValue *valu
 
 	str = gda_value_stringify ((GValue *) value);
 	if (str) {
-		str2 = gda_default_escape_chars (str);
+		if (hdl->priv->prov) 
+			str2 = gda_server_provider_escape_string (hdl->priv->prov, hdl->priv->cnc, str);
+		else 
+			str2 = gda_default_escape_string (str);
 		retval = g_strdup_printf ("'%s'", str2);
 		g_free (str2);
 		g_free (str);
@@ -215,7 +260,10 @@ gda_handler_string_get_value_from_sql (GdaDataHandler *iface, const gchar *sql,
 			gchar *unstr;
 
 			str[i-1] = 0;
-			unstr = gda_default_unescape_chars (str+1);
+			if (hdl->priv->prov)
+				unstr = gda_server_provider_unescape_string (hdl->priv->prov, hdl->priv->cnc, str+1);
+			else
+				unstr = gda_default_unescape_string (str+1);
 			if (unstr) {
 				value = g_value_init (g_new0 (GValue, 1), G_TYPE_STRING);
 				g_value_take_string (value, unstr);
@@ -260,7 +308,7 @@ gda_handler_string_get_sane_init_value (GdaDataHandler *iface, GType type)
 }
 
 static guint
-gda_handler_string_get_nb_gda_types (GdaDataHandler *iface)
+gda_handler_string_get_nb_g_types (GdaDataHandler *iface)
 {
 	GdaHandlerString *hdl;
 
@@ -268,12 +316,12 @@ gda_handler_string_get_nb_gda_types (GdaDataHandler *iface)
 	hdl = GDA_HANDLER_STRING (iface);
 	g_return_val_if_fail (hdl->priv, 0);
 
-	return hdl->priv->nb_gda_types;
+	return hdl->priv->nb_g_types;
 }
 
 
 static gboolean
-gda_handler_string_accepts_gda_type (GdaDataHandler *iface, GType type)
+gda_handler_string_accepts_g_type (GdaDataHandler *iface, GType type)
 {
 	GdaHandlerString *hdl;
 	guint i = 0;
@@ -284,8 +332,8 @@ gda_handler_string_accepts_gda_type (GdaDataHandler *iface, GType type)
 	hdl = GDA_HANDLER_STRING (iface);
 	g_return_val_if_fail (hdl->priv, 0);
 
-	while (!found && (i < hdl->priv->nb_gda_types)) {
-		if (hdl->priv->valid_gda_types [i] == type)
+	while (!found && (i < hdl->priv->nb_g_types)) {
+		if (hdl->priv->valid_g_types [i] == type)
 			found = TRUE;
 		i++;
 	}
@@ -294,16 +342,16 @@ gda_handler_string_accepts_gda_type (GdaDataHandler *iface, GType type)
 }
 
 static GType
-gda_handler_string_get_gda_type_index (GdaDataHandler *iface, guint index)
+gda_handler_string_get_g_type_index (GdaDataHandler *iface, guint index)
 {
 	GdaHandlerString *hdl;
 
 	g_return_val_if_fail (iface && GDA_IS_HANDLER_STRING (iface), G_TYPE_INVALID);
 	hdl = GDA_HANDLER_STRING (iface);
 	g_return_val_if_fail (hdl->priv, G_TYPE_INVALID);
-	g_return_val_if_fail (index < hdl->priv->nb_gda_types, G_TYPE_INVALID);
+	g_return_val_if_fail (index < hdl->priv->nb_g_types, G_TYPE_INVALID);
 
-	return hdl->priv->valid_gda_types[index];
+	return hdl->priv->valid_g_types[index];
 }
 
 static const gchar *
